@@ -3,7 +3,6 @@ package Text::Spintax;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
-use Text::Spintax::Mo;
 use Text::Spintax::grammar;
 use Text::Spintax::RenderNode;
 use Parse::Lex;
@@ -14,11 +13,11 @@ Text::Spintax - A parser and renderer for spintax formatted text.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -65,16 +64,23 @@ If you want every possible outcome to be equally likely, then call equal_path_we
 
 =cut
 
-has 'root' => (
-   is => 'rw',
-);
-
-has 'curr' => (
-   is => 'rw',
-);
+sub root { scalar @_ == 2 and $_[0]->{root} = $_[1]; return $_[0]->{root} }
+sub curr { scalar @_ == 2 and $_[0]->{curr} = $_[1]; return $_[0]->{curr} }
 
 =head1 SUBROUTINES/METHODS
 
+=head2 new
+
+   Returns a Text::Spintax object
+
+=cut
+
+sub new {
+   my $class = shift;
+   my $self = bless {}, $class;
+   return $self;
+}
+
 =head2 parse
 
    Parses the spintax and returns a Text::Spintax::Node that is suitable for rendering.
@@ -222,7 +228,6 @@ L<http://search.cpan.org/dist/Text-Spintax/>
 =head1 ACKNOWLEDGEMENTS
 
 Francois Desarmenien <francois@fdesar.net> for writing Parse::YAPP
-Ingy dot Net <ingy@ingy.net> for writing Mo and mo-inline
 Philippe Verdret for writing Parse::Lex
 
 =head1 LICENSE AND COPYRIGHT
